==> aws-java-sdk-devicefarm-1.10.61-sources.jar: com/amazonaws/services/devicefarm/model/transform/UploadJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.devicefarm.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.devicefarm.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * UploadMarshaller
 */
public class UploadJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a JSONWriter
     */
    public void marshall(Upload upload, JSONWriter jsonWriter) {
        if (upload == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonWriter.object();

            if (upload.getArn() != null) {
                jsonWriter.key("arn").value(upload.getArn());
            }
            if (upload.getName() != null) {
                jsonWriter.key("name").value(upload.getName());
            }
            if (upload.getCreated() != null) {
                jsonWriter.key("created").value(upload.getCreated());
            }
            if (upload.getType() != null) {
                jsonWriter.key("type").value(upload.getType());
            }
            if (upload.getStatus() != null) {
                jsonWriter.key("status").value(upload.getStatus());
            }
            if (upload.getUrl() != null) {
                jsonWriter.key("url").value(upload.getUrl());
            }
            if (upload.getMetadata() != null) {
                jsonWriter.key("metadata").value(upload.getMetadata());
            }
            if (upload.getContentType() != null) {
                jsonWriter.key("contentType").value(upload.getContentType());
            }
            if (upload.getMessage() != null) {
                jsonWriter.key("message").value(upload.getMessage());
            }

            jsonWriter.endObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static UploadJsonMarshaller instance;

    public static UploadJsonMarshaller getInstance() {
        if (instance == null)
            instance = new UploadJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-devicefarm-1.10.64.1-sources.jar: com/amazonaws/services/devicefarm/model/transform/UploadJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.devicefarm.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.devicefarm.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * UploadMarshaller
 */
public class UploadJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(Upload upload, SdkJsonGenerator jsonGenerator) {
        if (upload == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (upload.getArn() != null) {
                jsonGenerator.writeFieldName("arn").writeValue(upload.getArn());
            }
            if (upload.getName() != null) {
                jsonGenerator.writeFieldName("name").writeValue(
                        upload.getName());
            }
            if (upload.getCreated() != null) {
                jsonGenerator.writeFieldName("created").writeValue(
                        upload.getCreated());
            }
            if (upload.getType() != null) {
                jsonGenerator.writeFieldName("type").writeValue(
                        upload.getType());
            }
            if (upload.getStatus() != null) {
                jsonGenerator.writeFieldName("status").writeValue(
                        upload.getStatus());
            }
            if (upload.getUrl() != null) {
                jsonGenerator.writeFieldName("url").writeValue(upload.getUrl());
            }
            if (upload.getMetadata() != null) {
                jsonGenerator.writeFieldName("metadata").writeValue(
                        upload.getMetadata());
            }
            if (upload.getContentType() != null) {
                jsonGenerator.writeFieldName("contentType").writeValue(
                        upload.getContentType());
            }
            if (upload.getMessage() != null) {
                jsonGenerator.writeFieldName("message").writeValue(
                        upload.getMessage());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static UploadJsonMarshaller instance;

    public static UploadJsonMarshaller getInstance() {
        if (instance == null)
            instance = new UploadJsonMarshaller();
        return instance;
    }

}
